@@ -367,7 +367,7 @@ class sparkClient():
             partition_date: airflow execution date passed as a datetime.datetime object
         """
         if not file_name: file_name = F.input_file_name()
-        partition_date = str(partition_date.date())
+        # partition_date = str(partition_date.date())
         try: 
             df = df.withColumn('META_file_name', F.lit(file_name)) \
                         .withColumn('META_partition_date', F.lit(partition_date)) \
